/** @typedef {import('estree').ArrowFunctionExpression} ArrowFunctionExpression */
/** @typedef {import('estree').BinaryExpression} BinaryExpression */
/** @typedef {import('estree').CallExpression} CallExpression */
/** @typedef {import('estree').Comment} Comment */
/** @typedef {import('estree').ExportSpecifier} ExportSpecifier */
/** @typedef {import('estree').Expression} Expression */
/** @typedef {import('estree').FunctionDeclaration} FunctionDeclaration */
/** @typedef {import('estree').ImportDeclaration} ImportDeclaration */
/** @typedef {import('estree').ImportSpecifier} ImportSpecifier */
/** @typedef {import('estree').Literal} Literal */
/** @typedef {import('estree').LogicalExpression} LogicalExpression */
/** @typedef {import('estree').NewExpression} NewExpression */
/** @typedef {import('estree').Node} Node */
/** @typedef {import('estree').ObjectExpression} ObjectExpression */
/** @typedef {import('estree').Pattern} Pattern */
/** @typedef {import('estree').Property} Property */
/** @typedef {import('estree').PropertyDefinition} PropertyDefinition */
/** @typedef {import('estree').SequenceExpression} SequenceExpression */
/** @typedef {import('estree').SimpleCallExpression} SimpleCallExpression */
/** @typedef {import('estree').SwitchStatement} SwitchStatement */
/** @typedef {import('estree').VariableDeclaration} VariableDeclaration */
/** @typedef {import('estree').StaticBlock} StaticBlock */
/** @typedef {import('estree').PrivateIdentifier} PrivateIdenifier*/
/**
 * @typedef {{
 *   content: string;
 *   loc?: {
 *     start: { line: number; column: number; };
 *     end: { line: number; column: number; };
 *   };
 *   has_newline: boolean;
 * }} Chunk
 */
/**
 * @typedef {(node: any, state: State) => Chunk[]} Handler
 */
/**
 * @typedef {{
 *   indent: string;
 *   scope: any; // TODO import from periscopic
 *   scope_map: WeakMap<Node, any>;
 *   getName: (name: string) => string;
 *   deconflicted: WeakMap<Node, Map<string, string>>;
 *   comments: Comment[];
 * }} State
 */
/**
 * @param {Node} node
 * @param {State} state
 * @returns {Chunk[]}
 */
export function handle(node: Node, state: State): Chunk[];
export type ArrowFunctionExpression = import('estree').ArrowFunctionExpression;
export type BinaryExpression = import('estree').BinaryExpression;
export type CallExpression = import('estree').CallExpression;
export type Comment = import('estree').Comment;
export type ExportSpecifier = import('estree').ExportSpecifier;
export type Expression = import('estree').Expression;
export type FunctionDeclaration = import('estree').FunctionDeclaration;
export type ImportDeclaration = import('estree').ImportDeclaration;
export type ImportSpecifier = import('estree').ImportSpecifier;
export type Literal = import('estree').Literal;
export type LogicalExpression = import('estree').LogicalExpression;
export type NewExpression = import('estree').NewExpression;
export type Node = import('estree').Node;
export type ObjectExpression = import('estree').ObjectExpression;
export type Pattern = import('estree').Pattern;
export type Property = import('estree').Property;
export type PropertyDefinition = import('estree').PropertyDefinition;
export type SequenceExpression = import('estree').SequenceExpression;
export type SimpleCallExpression = import('estree').SimpleCallExpression;
export type SwitchStatement = import('estree').SwitchStatement;
export type VariableDeclaration = import('estree').VariableDeclaration;
export type StaticBlock = import('estree').StaticBlock;
export type PrivateIdenifier = import('estree').PrivateIdentifier;
export type Chunk = {
    content: string;
    loc?: {
        start: {
            line: number;
            column: number;
        };
        end: {
            line: number;
            column: number;
        };
    };
    has_newline: boolean;
};
export type Handler = (node: any, state: State) => Chunk[];
export type State = {
    indent: string;
    scope: any;
    scope_map: WeakMap<Node, any>;
    getName: (name: string) => string;
    deconflicted: WeakMap<Node, Map<string, string>>;
    comments: Comment[];
};
/** @param {Chunk[]} chunks */
declare function has_newline(chunks: Chunk[]): boolean;
export {};
